==> knative-model-4.7.1-sources.jar: io/fabric8/knative/v1/URLFluent.java <==
package io.fabric8.knative.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.knative.net.UserinfoFluent;
import io.fabric8.knative.net.UserinfoBuilder;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.knative.net.Userinfo;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface URLFluent<A extends URLFluent<A>> extends Fluent<A>{


    public Boolean isForceQuery();
    public A withForceQuery(Boolean forceQuery);
    public Boolean hasForceQuery();
    public A withNewForceQuery(String arg1);
    public A withNewForceQuery(boolean arg1);
    public String getFragment();
    public A withFragment(String fragment);
    public Boolean hasFragment();
    public A withNewFragment(String arg1);
    public A withNewFragment(StringBuilder arg1);
    public A withNewFragment(StringBuffer arg1);
    public String getHost();
    public A withHost(String host);
    public Boolean hasHost();
    public A withNewHost(String arg1);
    public A withNewHost(StringBuilder arg1);
    public A withNewHost(StringBuffer arg1);
    public String getOpaque();
    public A withOpaque(String opaque);
    public Boolean hasOpaque();
    public A withNewOpaque(String arg1);
    public A withNewOpaque(StringBuilder arg1);
    public A withNewOpaque(StringBuffer arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(String arg1);
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(StringBuffer arg1);
    public String getRawPath();
    public A withRawPath(String rawPath);
    public Boolean hasRawPath();
    public A withNewRawPath(String arg1);
    public A withNewRawPath(StringBuilder arg1);
    public A withNewRawPath(StringBuffer arg1);
    public String getRawQuery();
    public A withRawQuery(String rawQuery);
    public Boolean hasRawQuery();
    public A withNewRawQuery(String arg1);
    public A withNewRawQuery(StringBuilder arg1);
    public A withNewRawQuery(StringBuffer arg1);
    public String getScheme();
    public A withScheme(String scheme);
    public Boolean hasScheme();
    public A withNewScheme(String arg1);
    public A withNewScheme(StringBuilder arg1);
    public A withNewScheme(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildUser instead.
 * @return The buildable object.
 */
@Deprecated public Userinfo getUser();
    public Userinfo buildUser();
    public A withUser(Userinfo user);
    public Boolean hasUser();
    public URLFluent.UserNested<A> withNewUser();
    public URLFluent.UserNested<A> withNewUserLike(Userinfo item);
    public URLFluent.UserNested<A> editUser();
    public URLFluent.UserNested<A> editOrNewUser();
    public URLFluent.UserNested<A> editOrNewUserLike(Userinfo item);

    public interface UserNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,UserinfoFluent<URLFluent.UserNested<N>>{

        
    public N and();    public N endUser();
}


}

==> knative-model-4.9.0-sources.jar: io/fabric8/knative/v1/URLFluent.java <==
package io.fabric8.knative.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.knative.net.UserinfoFluent;
import io.fabric8.knative.net.UserinfoBuilder;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.knative.net.Userinfo;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface URLFluent<A extends URLFluent<A>> extends Fluent<A>{


    public Boolean isForceQuery();
    public A withForceQuery(Boolean forceQuery);
    public Boolean hasForceQuery();
    public A withNewForceQuery(String arg1);
    public A withNewForceQuery(boolean arg1);
    public String getFragment();
    public A withFragment(String fragment);
    public Boolean hasFragment();
    public A withNewFragment(String arg1);
    public A withNewFragment(StringBuilder arg1);
    public A withNewFragment(StringBuffer arg1);
    public String getHost();
    public A withHost(String host);
    public Boolean hasHost();
    public A withNewHost(String arg1);
    public A withNewHost(StringBuilder arg1);
    public A withNewHost(StringBuffer arg1);
    public String getOpaque();
    public A withOpaque(String opaque);
    public Boolean hasOpaque();
    public A withNewOpaque(String arg1);
    public A withNewOpaque(StringBuilder arg1);
    public A withNewOpaque(StringBuffer arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(String arg1);
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(StringBuffer arg1);
    public String getRawPath();
    public A withRawPath(String rawPath);
    public Boolean hasRawPath();
    public A withNewRawPath(String arg1);
    public A withNewRawPath(StringBuilder arg1);
    public A withNewRawPath(StringBuffer arg1);
    public String getRawQuery();
    public A withRawQuery(String rawQuery);
    public Boolean hasRawQuery();
    public A withNewRawQuery(String arg1);
    public A withNewRawQuery(StringBuilder arg1);
    public A withNewRawQuery(StringBuffer arg1);
    public String getScheme();
    public A withScheme(String scheme);
    public Boolean hasScheme();
    public A withNewScheme(String arg1);
    public A withNewScheme(StringBuilder arg1);
    public A withNewScheme(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildUser instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public Userinfo getUser();
    public Userinfo buildUser();
    public A withUser(Userinfo user);
    public Boolean hasUser();
    public URLFluent.UserNested<A> withNewUser();
    public URLFluent.UserNested<A> withNewUserLike(Userinfo item);
    public URLFluent.UserNested<A> editUser();
    public URLFluent.UserNested<A> editOrNewUser();
    public URLFluent.UserNested<A> editOrNewUserLike(Userinfo item);

    public interface UserNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,UserinfoFluent<URLFluent.UserNested<N>>{

        
    public N and();    public N endUser();
}


}
